@@ -5,8 +5,8 @@
  *
  *      Description:  Interface to x86 related functions for the access module.
  *
- *      Version:   4.3.2
- *      Released:  12.04.2018
+ *      Version:   4.3.3
+ *      Released:  09.11.2018
  *
  *      Author:   Thomas Roehl (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
@@ -66,7 +66,7 @@ access_x86_init(int cpu_id)
 int
 access_x86_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t *data)
 {
-    int err;
+    int err = -EINVAL;
     uint64_t tmp = 0x0ULL;
     if (dev == MSR_DEV)
     {
@@ -87,7 +87,7 @@ access_x86_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t *da
 int
 access_x86_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t data)
 {
-    int err;
+    int err = -EINVAL;
     if (dev == MSR_DEV)
     {
         err = access_x86_msr_write(cpu_id, reg, data);
