@@ -9,8 +9,8 @@
  *                  Allows to turn on and off the Hardware prefetcher
  *                  available.
  *
- *      Version:   4.3.2
- *      Released:  12.04.2018
+ *      Version:   4.3.3
+ *      Released:  09.11.2018
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *      Project:  likwid
@@ -44,6 +44,7 @@
 #include <registers.h>
 #include <textcolor.h>
 #include <likwid.h>
+#include <lock.h>
 
 /* #####   EXPORTED VARIABLES   ########################################### */
 
@@ -86,16 +87,11 @@ cpuFeatures_update(int cpu)
 {
     int ret;
     uint64_t flags = 0x0ULL;
-    if (cpuid_info.isIntel == 0)
-    {
-        return;
-    }
     ret = HPMread(cpu, MSR_DEV, MSR_IA32_MISC_ENABLE, &flags);
     if (ret != 0)
     {
         fprintf(stderr, "Cannot read register 0x%X on cpu %d: err %d\n", MSR_IA32_MISC_ENABLE, cpu, ret);
     }
-
     /*cpuFeatureFlags.fastStrings = 0;
     cpuFeatureFlags.thermalControl = 0;
     cpuFeatureFlags.perfMonitoring = 0;
@@ -261,6 +257,11 @@ cpuFeatures_init()
     {
         return;
     }
+    if (!lock_check())
+    {
+        fprintf(stderr,"Access to CPU feature backend is locked.\n");
+        return;
+    }
 
     topology_init();
     if (!cpuFeatureMask)
@@ -268,25 +269,24 @@ cpuFeatures_init()
         cpuFeatureMask = malloc(cpuid_topology.numHWThreads*sizeof(uint64_t));
         memset(cpuFeatureMask, 0, cpuid_topology.numHWThreads*sizeof(uint64_t));
     }
-    if (cpuid_info.isIntel == 0)
-    {
-        return;
-    }
+
     if (!HPMinitialized())
     {
         HPMinit();
-
-        for (int i = 0; i < cpuid_topology.numHWThreads; i++)
+    }
+    for (int i = 0; i < cpuid_topology.numHWThreads; i++)
+    {
+        int ret = HPMaddThread(cpuid_topology.threadPool[i].apicId);
+        if (ret != 0)
         {
-            int ret = HPMaddThread(cpuid_topology.threadPool[i].apicId);
-            if (ret != 0)
-            {
-                ERROR_PRINT(Cannot get access to register CPU feature register on CPU %d, cpuid_topology.threadPool[i].apicId);
-                return;
-            }
-            cpuFeatures_update(cpuid_topology.threadPool[i].apicId);
+            ERROR_PRINT(Cannot get access to register CPU feature register on CPU %d, cpuid_topology.threadPool[i].apicId);
+            return;
         }
     }
+    for (int i = 0; i < cpuid_topology.numHWThreads; i++)
+    {
+        cpuFeatures_update(cpuid_topology.threadPool[i].apicId);
+    }
 
     features_initialized = 1;
 }
@@ -334,6 +334,10 @@ cpuFeatures_enable(int cpu, CpuFeature type, int print)
     uint32_t reg = MSR_IA32_MISC_ENABLE;
     int newOffsets = 0;
     int knlOffsets = 0;
+    if (!features_initialized)
+    {
+        return -1;
+    }
     if (IF_FLAG(type))
     {
         return 0;
@@ -375,15 +379,10 @@ cpuFeatures_enable(int cpu, CpuFeature type, int print)
         if (type == FEAT_CL_PREFETCHER ||
             type == FEAT_IP_PREFETCHER)
         {
-            fprintf(stderr, "CL_PREFETCHER and IP_PREFETCHER not available on Intel Xeon Phi (KNL)\n");
+            fprintf(stderr, "CL_PREFETCHER and IP_PREFETCHER not available on Intel Xeon Phi (KNL)");
             return 0;
         }
     }
-    if (cpuid_info.isIntel == 0)
-    {
-        fprintf(stderr, "Enabling features is only available on Intel platforms\n");
-        return -EINVAL;
-    }
 
     ret = HPMread(cpu, MSR_DEV, reg, &flags);
     if (ret != 0)
@@ -491,6 +490,10 @@ cpuFeatures_disable(int cpu, CpuFeature type, int print)
     uint32_t reg = MSR_IA32_MISC_ENABLE;
     int newOffsets = 0;
     int knlOffsets = 1;
+    if (!features_initialized)
+    {
+        return -1;
+    }
     if (!IF_FLAG(type))
     {
         return 0;
@@ -536,11 +539,6 @@ cpuFeatures_disable(int cpu, CpuFeature type, int print)
             return 0;
         }
     }
-    if (cpuid_info.isIntel == 0)
-    {
-        fprintf(stderr, "Disabling features is only available on Intel platforms\n");
-        return -EINVAL;
-    }
     ret = HPMread(cpu, MSR_DEV, reg, &flags);
     if (ret != 0)
     {
@@ -644,6 +642,10 @@ cpuFeatures_disable(int cpu, CpuFeature type, int print)
 int
 cpuFeatures_get(int cpu, CpuFeature type)
 {
+    if (!features_initialized)
+    {
+        return -EINVAL;
+    }
     if ((type >= FEAT_HW_PREFETCHER) && (type < CPUFEATURES_MAX))
     {
         if (IF_FLAG(type))
