@@ -5,8 +5,8 @@
  *
  *      Description:  Module implementing an interface for frequency manipulation
  *
- *      Version:   4.3.2
- *      Released:  12.04.2018
+ *      Version:   4.3.3
+ *      Released:  09.11.2018
  *
  *      Author:   Thomas Roehl (tr), thomas.roehl@googlemail.com
  *                Jan Treibig (jt), jan.treibig@gmail.com
@@ -46,6 +46,7 @@
 #include <access.h>
 #include <registers.h>
 #include <cpuid.h>
+#include <lock.h>
 
 #include <frequency.h>
 #include <frequency_acpi.h>
@@ -93,6 +94,11 @@ static int freq_getDriver(const int cpu_id )
         bdestroy(bbuff);
     }
     fclose(f);
+    if (access(daemon_path, X_OK) != 0)
+    {
+        fprintf(stderr, "WARN: SetFreq daemon not found, cannot change settings\n");
+        drv = NOT_DETECTED;
+    }
     return 0;
 }
 
@@ -102,6 +108,7 @@ static int _freq_getUncoreMinMax(const int socket_id, int *cpuId, double* min, d
     *cpuId = -1;
     *min = 0;
     *max = 0;
+
     for (int i=0; i<cpuid_topology.numHWThreads; i++)
     {
         if (cpuid_topology.threadPool[i].packageId == socket_id)
@@ -271,6 +278,11 @@ uint64_t freq_setCpuClockMax(const int cpu_id, const uint64_t freq)
             return 0;
         }
     }
+    if (!lock_check())
+    {
+        fprintf(stderr,"Access to frequency backend is locked.\n");
+        return 0;
+    }
 
     cur = freq_getCpuClockMax(cpu_id);
     if (cur == freq)
@@ -343,6 +355,11 @@ uint64_t freq_setCpuClockMin(const int cpu_id, const uint64_t freq)
             return 0;
         }
     }
+    if (!lock_check())
+    {
+        fprintf(stderr,"Access to frequency backend is locked.\n");
+        return 0;
+    }
 
     cur = freq_getCpuClockMin(cpu_id);
     if (cur == freq)
@@ -438,11 +455,17 @@ static int getAMDTurbo(const int cpu_id)
     int err = 0;
     int own_hpm = 0;
 
+    if (!lock_check())
+    {
+        fprintf(stderr,"Access to frequency backend is locked.\n");
+        return 0;
+    }
+
     if (!HPMinitialized())
     {
         HPMinit();
         own_hpm = 1;
-        
+
         err = HPMaddThread(cpu_id);
         if (err != 0)
         {
@@ -468,12 +491,17 @@ static int setAMDTurbo(const int cpu_id, const int turbo)
 {
     int err = 0;
     int own_hpm = 0;
+    if (!lock_check())
+    {
+        fprintf(stderr,"Access to frequency backend is locked.\n");
+        return -EPERM;
+    }
 
     if (!HPMinitialized())
     {
         HPMinit();
         own_hpm = 1;
-        
+
         err = HPMaddThread(cpu_id);
         if (err != 0)
         {
@@ -489,7 +517,7 @@ static int setAMDTurbo(const int cpu_id, const int turbo)
         ERROR_PLAIN_PRINT(Cannot read register 0xC0010015);
         return err;
     }
-    
+
     if (turbo)
     {
         tmp &= ~(1ULL<<25);
@@ -515,6 +543,12 @@ static int getIntelTurbo(const int cpu_id)
     int err = 0;
     int own_hpm = 0;
 
+    if (!lock_check())
+    {
+        fprintf(stderr,"Access to frequency backend is locked.\n");
+        return 0;
+    }
+
     if (!HPMinitialized())
     {
         HPMinit();
@@ -544,12 +578,17 @@ static int setIntelTurbo(const int cpu_id, const int turbo)
 {
     int err = 0;
     int own_hpm = 0;
+    if (!lock_check())
+    {
+        fprintf(stderr,"Access to frequency backend is locked.\n");
+        return -EPERM;
+    }
 
     if (!HPMinitialized())
     {
         HPMinit();
         own_hpm = 1;
-        
+
         err = HPMaddThread(cpu_id);
         if (err != 0)
         {
@@ -565,7 +604,6 @@ static int setIntelTurbo(const int cpu_id, const int turbo)
         ERROR_PRINT(Cannot read register 0x%x, MSR_IA32_MISC_ENABLE);
         return err;
     }
-    
     if (turbo)
     {
         tmp &= ~(1ULL << 38);
@@ -623,6 +661,11 @@ int freq_setTurbo(const int cpu_id, const int turbo)
             return 0;
         }
     }
+    if (!lock_check())
+    {
+        fprintf(stderr,"Access to frequency backend is locked.\n");
+        return 0;
+    }
 
     sprintf(cmd, "%s %d tur %d", daemon_path, cpu_id, turbo);
     if ( !(fpipe = (FILE*)popen(cmd,"r")) )
@@ -651,6 +694,11 @@ int freq_setGovernor(const int cpu_id, const char* gov)
             return 0;
         }
     }
+    if (!lock_check())
+    {
+        fprintf(stderr,"Access to frequency backend is locked.\n");
+        return 0;
+    }
 
     sprintf(buff, "%s", daemon_path);
     if (access(buff, X_OK))
@@ -756,7 +804,7 @@ char * freq_getAvailGovs(const int cpu_id )
         freq_getDriver(cpu_id);
         if (drv == NOT_DETECTED)
         {
-            return 0;
+            return NULL;
         }
     }
 
@@ -807,6 +855,11 @@ int freq_setUncoreFreqMin(const int socket_id, const uint64_t freq)
     int cpuId = -1;
     uint64_t f = freq / 100;
     double fmin, fmax;
+    if (!lock_check())
+    {
+        fprintf(stderr,"Access to frequency backend is locked.\n");
+        return -EPERM;
+    }
     if (isAMD())
     {
         return 0;
@@ -868,6 +921,12 @@ uint64_t freq_getUncoreFreqMin(const int socket_id)
     int err = 0;
     int own_hpm = 0;
     int cpuId = -1;
+
+    if (!lock_check())
+    {
+        fprintf(stderr,"Access to frequency backend is locked.\n");
+        return 0;
+    }
     if (isAMD())
     {
         return 0;
@@ -918,6 +977,11 @@ int freq_setUncoreFreqMax(const int socket_id, const uint64_t freq)
     int cpuId = -1;
     uint64_t f = freq / 100;
     double fmin, fmax;
+    if (!lock_check())
+    {
+        fprintf(stderr,"Access to frequency backend is locked.\n");
+        return -EPERM;
+    }
     if (isAMD())
     {
         return 0;
@@ -965,6 +1029,7 @@ int freq_setUncoreFreqMax(const int socket_id, const uint64_t freq)
         ERROR_PRINT(Cannot write register 0x%X on CPU %d, MSR_UNCORE_FREQ, cpuId);
         return err;
     }
+
     if (own_hpm)
         HPMfinalize();
     return 0;
@@ -975,6 +1040,13 @@ uint64_t freq_getUncoreFreqMax(const int socket_id)
     int err = 0;
     int own_hpm = 0;
     int cpuId = -1;
+
+    if (!lock_check())
+    {
+        fprintf(stderr,"Access to frequency backend is locked.\n");
+        return 0;
+    }
+
     if (isAMD())
     {
         return 0;
@@ -1017,3 +1089,57 @@ uint64_t freq_getUncoreFreqMax(const int socket_id)
         HPMfinalize();
     return tmp;
 }
+
+uint64_t freq_getUncoreFreqCur(const int socket_id)
+{
+    int err = 0;
+    int own_hpm = 0;
+    int cpuId = -1;
+
+    if (!lock_check())
+    {
+        fprintf(stderr,"Access to frequency backend is locked.\n");
+        return 0;
+    }
+    if (isAMD())
+    {
+        return 0;
+    }
+    for (int i=0; i<cpuid_topology.numHWThreads; i++)
+    {
+        if (cpuid_topology.threadPool[i].packageId == socket_id)
+        {
+            cpuId = cpuid_topology.threadPool[i].apicId;
+            break;
+        }
+    }
+    if (cpuId < 0)
+    {
+        ERROR_PRINT(Unknown socket ID %d, socket_id);
+        return 0;
+    }
+    if (!HPMinitialized())
+    {
+        HPMinit();
+        own_hpm = 1;
+        err = HPMaddThread(cpuId);
+        if (err != 0)
+        {
+            ERROR_PLAIN_PRINT(Cannot get access to MSRs)
+            return 0;
+        }
+    }
+
+    uint64_t tmp = 0x0ULL;
+    err = HPMread(cpuId, MSR_DEV, MSR_UNCORE_FREQ_READ, &tmp);
+    if (err)
+    {
+        //ERROR_PRINT(Cannot read register 0x%X on CPU %d, MSR_UNCORE_FREQ_READ, cpuId);
+        return 0;
+    }
+    tmp = (tmp & 0xFFULL) * 100;
+
+    if (own_hpm)
+        HPMfinalize();
+    return tmp;
+}
