@@ -5,8 +5,8 @@
  *
  *      Description: Counter Header File of perfmon module for Intel Pentium M.
  *
- *      Version:   4.3.2
- *      Released:  12.04.2018
+ *      Version:   4.3.3
+ *      Released:  09.11.2018
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Roehl (tr), thomas.roehl@googlemail.com
@@ -40,5 +40,5 @@ static RegisterMap pm_counter_map[NUM_COUNTERS_PM] = {
 };
 
 static BoxMap pm_box_map[NUM_UNITS] = {
-    [PMC] = {0, 0, 0, 0, 0, 0, 48}
+    [PMC] = {0, 0, 0, 0, 0, 0, 48, 0, 0},
 };
