@@ -5,8 +5,8 @@
  *
  *      Description:  Header file of perfmon module for Intel Atom (Silvermont)
  *
- *      Version:   4.3.2
- *      Released:  12.04.2018
+ *      Version:   4.3.3
+ *      Released:  09.11.2018
  *
  *      Author:   Thomas Roehl (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
@@ -47,6 +47,7 @@ int perfmon_init_silvermont(int cpu_id)
 uint32_t svm_fixed_setup(int cpu_id, RegisterIndex index, PerfmonEvent *event)
 {
     uint32_t flags = (1ULL<<(1+(index*4)));
+    cpu_id++;
     if (event->numberOfOptions > 0)
     {
         for(int i=0;i<event->numberOfOptions;i++)
@@ -163,16 +164,9 @@ int perfmon_setupCountersThread_silvermont(
         int thread_id,
         PerfmonEventSet* eventSet)
 {
-    int haveLock = 0;
-    uint64_t flags = 0x0ULL;
     uint64_t fixed_flags = 0x0ULL;
     int cpu_id = groupSet->threads[thread_id].processorId;
 
-    if (socket_lock[affinity_thread2socket_lookup[cpu_id]] == cpu_id)
-    {
-        haveLock = 1;
-    }
-
     if (MEASURE_CORE(eventSet))
     {
         CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, MSR_PERF_GLOBAL_CTRL, 0x0ULL));
@@ -186,7 +180,6 @@ int perfmon_setupCountersThread_silvermont(
         {
             continue;
         }
-        flags = 0x0ULL;
         RegisterIndex index = eventSet->events[i].index;
         PerfmonEvent *event = &(eventSet->events[i].event);
         eventSet->events[i].threadCounter[thread_id].init = TRUE;
