@@ -5,8 +5,8 @@
  *
  *      Description:  Counter Header File of perfmon module for Intel Skylake X.
  *
- *      Version:   4.3.2
- *      Released:  12.04.2018
+ *      Version:   4.3.3
+ *      Released:  09.11.2018
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Roehl (tr), thomas.roehl@googlemail.com
@@ -420,7 +420,7 @@ static RegisterMap skylakeX_counter_map[NUM_COUNTERS_SKYLAKEX] = {
 
 
 static BoxMap skylakeX_box_map[NUM_UNITS] = {
-    [PMC] = {MSR_PERF_GLOBAL_CTRL, MSR_V4_PERF_GLOBAL_STATUS, MSR_V4_PERF_GLOBAL_STATUS_RESET, 0, 0, 0, 48},
+    [PMC] = {MSR_PERF_GLOBAL_CTRL, MSR_V4_PERF_GLOBAL_STATUS, MSR_V4_PERF_GLOBAL_STATUS_RESET, 0, 0, 0, 48, MSR_PEBS_LD_LAT},
     [THERMAL] = {0, 0, 0, 0, 0, 0, 8},
     [FIXED] =  {MSR_PERF_GLOBAL_CTRL, MSR_V4_PERF_GLOBAL_STATUS, MSR_V4_PERF_GLOBAL_STATUS_RESET, 0, 0, 0, 48},
     [POWER] = {0, 0, 0, 0, 0, 0, 32},
