@@ -4,8 +4,8 @@
 !
 !     Description: Marker API f90 module
 !
-!      Version:   4.3.2
-!      Released:  12.04.2018
+!      Version:   4.3.3
+!      Released:  09.11.2018
 !
 !     Authors:  Jan Treibig (jt), jan.treibig@gmail.com,
 !               Thomas Roehl (tr), thomas.roehl@googlemail.com
@@ -117,6 +117,13 @@ interface
   INTEGER :: count
   end subroutine likwid_markerGetRegion
 
+!> \ingroup Fortran_Interface
+!! \brief Reset the counters for a code region to zero
+  subroutine likwid_markerResetRegion( regionTag )
+!> \param regionTag Name for the code region for later identification
+  character(*) :: regionTag
+  end subroutine likwid_markerResetRegion
+
 end interface
 
 end module likwid
