@@ -5,8 +5,8 @@
  *
  *      Description:  Module implementing Intel RAPL interface
  *
- *      Version:   4.3.2
- *      Released:  12.04.2018
+ *      Version:   4.3.3
+ *      Released:  09.11.2018
  *
  *      Authors:  Jan Treibig (jt), jan.treibig@gmail.com,
  *                Thomas Roehl (tr), thomas.roehl@googlemail.com
@@ -38,6 +38,7 @@
 #include <types.h>
 #include <power.h>
 #include <topology.h>
+#include <lock.h>
 
 /* #####   EXPORTED VARIABLES   ########################################### */
 
@@ -60,7 +61,7 @@ power_init(int cpuId)
 
     /* determine Turbo Mode features */
     double busSpeed;
-    if (power_initialized)
+    if (power_initialized || !lock_check())
     {
         return 0;
     }
