@@ -5,8 +5,8 @@
  *
  *      Description:  Module implementing Intel TM/TM2 interface
  *
- *      Version:   4.3.2
- *      Released:  12.04.2018
+ *      Version:   4.3.3
+ *      Released:  09.11.2018
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *      Project:  likwid
@@ -37,6 +37,7 @@
 #include <types.h>
 #include <thermal.h>
 #include <topology.h>
+#include <lock.h>
 
 /* #####   EXPORTED VARIABLES   ########################################### */
 
@@ -48,6 +49,11 @@ void
 thermal_init(int cpuId)
 {
     uint64_t flags=0ULL;
+    if (!lock_check())
+    {
+        fprintf(stderr,"Access to thermal backend is locked.\n");
+        return;
+    }
     HPMinit();
     if (HPMaddThread(cpuId) < 0)
         fprintf(stderr, "Cannot initialize access to registers on CPU %d\n", cpuId);
